/** ColEm: portable Coleco emulator **************************/
/**                                                         **/
/**                       AdamNet.h                         **/
/**                                                         **/
/** This file contains declarations for the AdamNet I/O     **/
/** interface found in Coleco Adam home computer.           **/
/**                                                         **/
/** Copyright (C) Marat Fayzullin 1994-2020                 **/
/**     You are not allowed to distribute this software     **/
/**     commercially. Please, notify me, if you make any    **/
/**     changes to this file.                               **/
/*************************************************************/
#ifndef ADAMNET_H
#define ADAMNET_H
#ifdef __cplusplus
extern "C" {
#endif

/** Adam Key Codes *******************************************/
#define KEY_CONTROL    CON_CONTROL
#define KEY_SHIFT      CON_SHIFT
#define KEY_ESC        27
#define KEY_BS         8 
#define KEY_TAB        9
#define KEY_ENTER      13 
#define KEY_QUOTE      '\''
#define KEY_BQUOTE     '`'
#define KEY_BSLASH     '\\'
#define KEY_COMMA      ','
#define KEY_DOT        '.'
#define KEY_SLASH      '/'
#define KEY_ASTERISK   '*'
#define KEY_F1         129
#define KEY_F2         130
#define KEY_F3         131
#define KEY_F4         132
#define KEY_F5         133
#define KEY_F6         134
#define KEY_F7         144 // ???
#define KEY_F8         145 // ???
#define KEY_HOME       171
#define KEY_UP         160
#define KEY_PGUP       168
#define KEY_LEFT       163
#define KEY_CENTER     128 // ???
#define KEY_RIGHT      161
#define KEY_END        170
#define KEY_DOWN       162
#define KEY_PGDN       169
#define KEY_INS        148
#define KEY_DEL        151
                       
#define KEY_HOME_EX    146
#define KEY_PGUP_EX    159
#define KEY_END_EX     147
#define KEY_PGDN_EX    149

#ifndef BYTE_TYPE_DEFINED
#define BYTE_TYPE_DEFINED
typedef unsigned char byte;
#endif

#ifndef WORD_TYPE_DEFINED
#define WORD_TYPE_DEFINED
typedef unsigned short word;
#endif

/** ReadPCB() ************************************************/
/** Read value from a given PCB or DCB address.             **/
/*************************************************************/
void ReadPCB(word A);

/** WritePCB() ***********************************************/
/** Write value to a given PCB or DCB address.              **/
/*************************************************************/
void WritePCB(word A,byte V);

/** ResetPCB() ***********************************************/
/** Reset PCB and attached hardware.                        **/
/*************************************************************/
void ResetPCB(void);

/** PutKBD() *************************************************/
/** Add a new key to the keyboard buffer.                   **/
/*************************************************************/
void PutKBD(unsigned int Key);

#ifdef __cplusplus
}
#endif
#endif /* ADAMNET_H */
